@@ -213,13 +213,13 @@ class MVPoly(object) :
 
 
     @classmethod
-    def berenstein(cls, i, n, **kwargs) :
+    def bernstein(cls, i, n, **kwargs) :
         """
-        Return the output of :meth:`mvpoly.dict.MVPolyDict.berenstein` 
+        Return the output of :meth:`mvpoly.dict.MVPolyDict.bernstein` 
         converted to other polynomial subclasess.
         """
         from mvpoly.dict import MVPolyDict
-        return cls(MVPolyDict.berenstein(i, n, **kwargs), **kwargs)
+        return cls(MVPolyDict.bernstein(i, n, **kwargs), **kwargs)
 
     @classmethod
     def lehmer(cls, **kwargs) :
