@@ -31,68 +31,6 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         self._coef = np.array([] if coef is None else coef, 
                               dtype = self.dtype)
 
-
-    @classmethod
-    def init_from_nonzero(self, p, dtype) :
-        """
-        Create a polynomial from a polynomial of any subclass; this is 
-        used internally by the 
-        :py:meth:`~mvpoly.cube.MVPolyCube.__init__` constructor, but
-        may be useful for direct application.
-        """
-        shp  = tuple(1+d for d in p.degrees)
-        nvar = len(shp)
-        coef = np.zeros(shp, dtype=dtype)
-        for pair in p.nonzero :
-            idx, val = pair
-            idx = idx + tuple(0 for _ in range(nvar - len(idx)))
-            coef[idx] = val
-        return MVPolyCube(coef, dtype=dtype)
-
-    @classmethod
-    def monomials(self, n, **kwd) :
-        """
-        Return a *n*-tuple of each of the monomials (*x*, *y*, ..) 
-        of an *n*-variate system.
-        """
-        return [self.monomial(i, n, **kwd) for i in range(n)]
-
-    @classmethod
-    def monomial(self, i, n, **kwd) :
-        """
-        Return the *i*-th monomial of an *n*-variate system,
-        (*i* = 0, ..., *n*-1).
-        """
-        shp = tuple((1 if j==i else 0) for j in range(n))
-        m = np.zeros([s+1 for s in shp], **kwd)
-        m.itemset(shp, 1)
-        return MVPolyCube(m, **kwd)
-
-    @classmethod
-    def zero(self, **kwd) :
-        """
-        Return the zero polynomial.
-        """
-        return MVPolyCube(**kwd)
-
-    @classmethod
-    def one(self, **kwd) :
-        """
-        Return the unit (1) polynomial.
-        """
-        return MVPolyCube(1, **kwd)
-
-    @property
-    def coef(self) :
-        """
-        The NumPy array of coefficients.
-        """
-        return self._coef
-
-    @coef.setter
-    def coef(self, value) :
-        self._coef = np.array(value, dtype=self.dtype)
-
     def __getitem__(self, key) :
         """
         The get-index method which returns the coefficients of the
@@ -172,6 +110,13 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         return self.__add__(other)
 
+    def __neg__(self) :
+        """
+        Negation of a polynomial, return the polynomial with negated 
+        coefficients.
+        """
+        return MVPolyCube(-(self.coef), dtype = self.dtype)
+
     def __mul__(self, other) :
         """
         Convolve our coefficient array with that of *other*
@@ -195,33 +140,29 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         return self.__mul__(other)
 
-    def __neg__(self) :
-        """
-        Negation of a polynomial, return the polynomial with negated 
-        coefficients.
-        """
-        return MVPolyCube(-(self.coef), dtype = self.dtype)
-
     def __eq__(self, other) :
         """
         Equality of polynomials. 
         """
         return ((self - other).coef == 0).all()
 
+    def astype(self, dtype) :
+        """
+        Return a polynomial using the specified *dtype* for the
+        coefficients.
+        """
+        return MVPolyCube(self.coef.astype(dtype), dtype=dtype)
+
     @property
-    def nonzero(self) :
+    def coef(self) :
         """
-        Returns a list of 2-element tuples, for each the first
-        being a (monomial) index, the second the corresponding 
-        coefficient. The indices have trailing zeros, so the return 
-        value for the polynomial
-        :math:`p(x,y) = 2 + 3x + 4y` would be
-        ``[((0,0), 2), ((1,0), 3), ((0,1), 4)]``.
+        The NumPy array of coefficients.
         """
-        dt = self.dtype
-        nzidx = np.nonzero(self.coef)
-        return zip((tuple(idx) for idx in np.transpose(nzidx)), 
-                   (np.array(c, dtype=dt) for c in self.coef[nzidx]))
+        return self._coef
+
+    @coef.setter
+    def coef(self, value) :
+        self._coef = np.array(value, dtype=self.dtype)
 
     @property
     def degrees(self) :
@@ -248,13 +189,6 @@ class MVPolyCube(mvpoly.base.MVPoly) :
             return -1
         return np.max(degs)
 
-    def astype(self, dtype) :
-        """
-        Return a polynomial using the specified *dtype* for the
-        coefficients.
-        """
-        return MVPolyCube(self.coef.astype(dtype), dtype=dtype)
-
     def eval(self, *args) :
         """
         Evaluate the polynomial at the points given by *args*.
@@ -341,3 +275,119 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         is installed (and that is in an early stage of development).
         """
         return mvpoly.util.cube.maxmodnb(self.coef, **kwargs)
+
+    @property
+    def nonzero(self) :
+        """
+        Returns a list of 2-element tuples, for each the first
+        being a (monomial) index, the second the corresponding 
+        coefficient. The indices have trailing zeros, so the return 
+        value for the polynomial
+        :math:`p(x,y) = 2 + 3x + 4y` would be
+        ``[((0,0), 2), ((1,0), 3), ((0,1), 4)]``.
+        """
+        dt = self.dtype
+        nzidx = np.nonzero(self.coef)
+        return zip((tuple(idx) for idx in np.transpose(nzidx)), 
+                   (np.array(c, dtype=dt) for c in self.coef[nzidx]))
+
+    def norm(self, order) :
+        """
+        Returns the *norm* of the coefficients.  The *order*
+        can be a float (for the p-norm) or any other value
+        accepted by the :meth:`numpy.linalg.norm` method. 
+        """
+        if self.coef.size > 0 :
+            return np.linalg.norm(self.coef.flat, order);
+        else :
+            return 0
+
+    @classmethod
+    def init_from_nonzero(cls, p, dtype) :
+        """
+        Create a polynomial from a polynomial of any subclass; this is 
+        used internally by the 
+        :py:meth:`~mvpoly.cube.MVPolyCube.__init__` constructor, but
+        may be useful for direct application.
+        """
+        shp  = tuple(1+d for d in p.degrees)
+        nvar = len(shp)
+        coef = np.zeros(shp, dtype=dtype)
+        for pair in p.nonzero :
+            idx, val = pair
+            idx = idx + tuple(0 for _ in range(nvar - len(idx)))
+            coef[idx] = val
+        return cls(coef, dtype=dtype)
+
+    @classmethod
+    def monomials(cls, n, **kwd) :
+        """
+        Return a *n*-tuple of each of the monomials (*x*, *y*, ..) 
+        of an *n*-variate system.
+        """
+        return [cls.monomial(i, n, **kwd) for i in range(n)]
+
+    @classmethod
+    def monomial(cls, i, n, **kwd) :
+        """
+        Return the *i*-th monomial of an *n*-variate system,
+        (*i* = 0, ..., *n*-1).
+        """
+        shp = tuple((1 if j==i else 0) for j in range(n))
+        m = np.zeros([s+1 for s in shp], **kwd)
+        m.itemset(shp, 1)
+        return cls(m, **kwd)
+
+    @classmethod
+    def zero(cls, **kwd) :
+        """
+        Return the zero polynomial.
+        """
+        return cls(**kwd)
+
+    @classmethod
+    def one(cls, **kwd) :
+        """
+        Return the unit (1) polynomial.
+        """
+        return cls(1, **kwd)
+
+    @classmethod
+    def lehmer(cls, **kwargs) :
+        """
+        Returns the 
+        `Lehmer polynomial <http://en.wikipedia.org/wiki/Lehmer%27s_conjecture>`_
+        (univariate of degree 10), notable as the polynomial whose
+        Mahler measure is the smallest known measure larger than 1 of a 
+        polynomial with integer coefficients.
+        """
+        dtype = kwargs.get('dtype', int)
+        kwargs['dtype'] = dtype
+        coef = np.array([1, 1, 0, -1, -1, -1, -1, -1, 0, 1, 1], dtype=dtype)
+        return MVPolyCube(coef, **kwargs)
+
+
+    @classmethod
+    def rudin_shapiro(cls, n, **kwargs) :
+        """
+        Returns the *n*-th 
+        `Rudin-Shapiro polynomial <http://en.wikipedia.org/wiki/Rudin-Shapiro_polynomials>`_ 
+        (univariate, of degree :math:`2^n-1`). These dense polynomials have
+        coefficients which are :math:`\pm1` and have a small
+        maximum modulus on the unit disk.
+        """
+        dtype = kwargs.get('dtype', int)
+        kwargs['dtype'] = dtype
+
+        p = np.array([1], dtype=dtype)        
+        q = np.array([1], dtype=dtype)
+
+        for i in range(n) :
+            p1 = p
+            p  = np.hstack((p1, q))
+            q  = np.hstack((p1, -q))
+
+        return MVPolyCube(p, **kwargs)
+
+
+
