@@ -714,27 +714,27 @@ class TestMVPolyLehmer(unittest.TestCase) :
             self.assertTrue(p == q, "rudin-shapiro explicit")
             
 
-class TestMVPolyBerenstein(unittest.TestCase) :
+class TestMVPolyBernstein(unittest.TestCase) :
 
-    def test_berenstein_size(self) :
+    def test_bernstein_size(self) :
         for C in classes :
-            p = C.berenstein((3, 2), (5, 7), dtype=int)
-            self.assertTrue(p.degrees == (5,7), "berenstein degrees")
+            p = C.bernstein((3, 2), (5, 7), dtype=int)
+            self.assertTrue(p.degrees == (5,7), "bernstein degrees")
 
-    def test_berenstein_badargs(self) :
+    def test_bernstein_badargs(self) :
         for C in classes :
-            self.assertRaises(ValueError, C.berenstein, (3, 8), (5, 7))
-            self.assertRaises(ValueError, C.berenstein, (1, 2, 3), (5, 7))
+            self.assertRaises(ValueError, C.bernstein, (3, 8), (5, 7))
+            self.assertRaises(ValueError, C.bernstein, (1, 2, 3), (5, 7))
 
-    def test_berenstein_explicit_1d(self) :
+    def test_bernstein_explicit_1d(self) :
         for C in classes :
-            p = C.berenstein(3, 4, dtype=int)
+            p = C.bernstein(3, 4, dtype=int)
             x = C.monomial(0, 1, dtype=int)
             q = 4 * x**3 * (1 - x)
-            self.assertTrue(p == q, "berenstein explicit 1d")
+            self.assertTrue(p == q, "bernstein explicit 1d")
 
-    def test_berenstein_dtype(self) :
+    def test_bernstein_dtype(self) :
         for C in classes :
             for dt in [int, float, np.double] :
-                p = C.berenstein((3,2), (5,7), dtype=dt)
+                p = C.bernstein((3,2), (5,7), dtype=dt)
                 self.assertTrue(p.dtype == dt, "rudin-shapiro dtype")
